@@ -1,6 +1,6 @@
 from plotly.basedatatypes import BaseTraceType as _BaseTraceType
 import copy as _copy
-from warnings import warn
+import warnings
 
 
 class Choroplethmapbox(_BaseTraceType):
@@ -2380,7 +2380,7 @@ an instance of :class:`plotly.graph_objs.Choroplethmapbox`"""
         # ------------------
         self._skip_invalid = False
 
-        warn(
+        warnings.warn(
             "*choroplethmapbox* is deprecated!"
             + " Use *choroplethmap* instead."
             + " Learn more at: https://plotly.com/python/mapbox-to-maplibre/",
