@@ -7,6 +7,5 @@ class XsrcValidator(_plotly_utils.basevalidators.SrcValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "none"),
-            role=kwargs.pop("role", "info"),
-            **kwargs
+            **kwargs,
         )
