@@ -9,6 +9,5 @@ class OpacityValidator(_plotly_utils.basevalidators.NumberValidator):
             edit_type=kwargs.pop("edit_type", "arraydraw"),
             max=kwargs.pop("max", 1),
             min=kwargs.pop("min", 0),
-            role=kwargs.pop("role", "info"),
-            **kwargs
+            **kwargs,
         )
