@@ -6,12 +6,11 @@ class OutlinecolorValidator(_plotly_utils.basevalidators.ColorValidator):
         self,
         plotly_name="outlinecolor",
         parent_name="scattermapbox.marker.colorbar",
-        **kwargs
+        **kwargs,
     ):
         super(OutlinecolorValidator, self).__init__(
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "calc"),
-            role=kwargs.pop("role", "style"),
-            **kwargs
+            **kwargs,
         )
